==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_snmp/com/clustercontrol/snmp/factory/AddMonitorSnmpString.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmp.factory;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.run.factory.AddMonitorStringValueType;
import com.clustercontrol.snmp.ejb.session.MonitorSnmpRunManagementHome;
import com.clustercontrol.snmp.util.ControlSnmpInfo;

/**
 * SNMP監視 文字列監視設定を登録するファクトリークラス<BR>
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class AddMonitorSnmpString extends AddMonitorStringValueType{
	
	protected static Log m_log = LogFactory.getLog( AddMonitorSnmpString.class );
	
	/* (non-Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	public boolean addCheckInfo() throws CreateException, NamingException{
		
		// SNMP監視情報を追加
		ControlSnmpInfo snmp = new ControlSnmpInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());
		return snmp.add(m_monitorInfo.getSnmpCheckInfo());
	}

	/* (non-Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#getJndiName()
	 */
	@Override
	public String getJndiName() {
		return MonitorSnmpRunManagementHome.JNDI_NAME;
	}
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_snmp/com/clustercontrol/snmp/factory/AddMonitorSnmpString.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.snmp.factory;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import com.clustercontrol.commons.scheduler.TriggerScheduler;
import com.clustercontrol.monitor.run.factory.AddMonitor;
import com.clustercontrol.monitor.run.factory.AddMonitorStringValueType;
import com.clustercontrol.snmp.util.ControlSnmpInfo;

/**
 * SNMP監視 文字列監視設定を登録するファクトリークラス<BR>
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class AddMonitorSnmpString extends AddMonitorStringValueType{

	/* (non-Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	protected boolean addCheckInfo() throws CreateException, NamingException{

		// SNMP監視情報を追加
		ControlSnmpInfo snmp = new ControlSnmpInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());
		return snmp.add(m_monitorInfo.getSnmpCheckInfo());
	}

	/**
	 * スケジュール実行の遅延時間を返します。
	 */
	@Override
	protected int getDelayTime() {
		return AddMonitor.getDelayTimeBasic(m_monitorInfo);
	}

	/**
	 * スケジュール実行種別を返します。
	 */
	@Override
	protected String getTriggerType() {
		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
	}
}
